pub struct Queue {
pub connection_pool: Pool<ConnectionManager<PgConnection>>,
}Expand description
An async queue that can be used to enqueue tasks.
It uses a PostgreSQL storage. It must be connected to perform any operation.
To connect a Queue to the PostgreSQL database call the get_connection method.
A Queue can be created with the TypedBuilder.
// Set DATABASE_URL enviroment variable if you would like to try this function.
pub fn connection_pool(pool_size: u32) -> r2d2::Pool<r2d2::ConnectionManager<PgConnection>> {
let database_url = env::var("DATABASE_URL").expect("DATABASE_URL must be set");
let manager = r2d2::ConnectionManager::<PgConnection>::new(database_url);
r2d2::Pool::builder()
.max_size(pool_size)
.build(manager)
.unwrap()
}
let queue = Queue::builder().connection_pool(connection_pool(3)).build();Fields
connection_pool: Pool<ConnectionManager<PgConnection>>Implementations
Sourceimpl Queue
impl Queue
Sourcepub fn get_connection(&self) -> Result<PoolConnection, QueueError>
pub fn get_connection(&self) -> Result<PoolConnection, QueueError>
Connect to the db if not connected
pub fn schedule_task_query( connection: &mut PgConnection, params: &dyn Runnable, ) -> Result<Task, QueueError>
pub fn insert_query( connection: &mut PgConnection, params: &dyn Runnable, scheduled_at: DateTime<Utc>, ) -> Result<Task, QueueError>
pub fn fetch_task_query( connection: &mut PgConnection, task_type: String, ) -> Option<Task>
pub fn fetch_and_touch_query( connection: &mut PgConnection, task_type: String, ) -> Result<Option<Task>, QueueError>
pub fn find_task_by_id_query( connection: &mut PgConnection, id: &Uuid, ) -> Option<Task>
pub fn remove_all_tasks_query( connection: &mut PgConnection, ) -> Result<usize, QueueError>
pub fn remove_all_scheduled_tasks_query( connection: &mut PgConnection, ) -> Result<usize, QueueError>
pub fn remove_tasks_of_type_query( connection: &mut PgConnection, task_type: &str, ) -> Result<usize, QueueError>
pub fn remove_task_by_metadata_query( connection: &mut PgConnection, task: &dyn Runnable, ) -> Result<usize, QueueError>
pub fn remove_task_query( connection: &mut PgConnection, id: &Uuid, ) -> Result<usize, QueueError>
pub fn update_task_state_query( connection: &mut PgConnection, task: &Task, state: FangTaskState, ) -> Result<Task, QueueError>
pub fn fail_task_query( connection: &mut PgConnection, task: &Task, error: &str, ) -> Result<Task, QueueError>
pub fn schedule_retry_query( connection: &mut PgConnection, task: &Task, backoff_seconds: u32, error: &str, ) -> Result<Task, QueueError>